@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudwatch._jsii
@@ -20,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-elasticloadbalancingv2",
-    "1.58.0",
+    "1.67.0",
     __name__[0:-6],
-    "aws-elasticloadbalancingv2@1.58.0.jsii.tgz",
+    "aws-elasticloadbalancingv2@1.67.0.jsii.tgz",
 )
 
 __all__ = [
